.. include:: ../README.rst

Contents
========

.. toctree::
	:maxdepth: 2

        auto_examples/index
        api
        Fork dicodile on Github <https://github.com/tomMoral/dicodile>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
